@@ -45,7 +45,7 @@ done
 case $platform in
 	Darwin)
 		cmd="brew install"
-		pkgs="openssl@1.1"
+		pkgs="openssl@3"
 		;;
 	Linux-ubuntu*)
 		cmd="apt-get install --no-install-recommends -y"
@@ -55,6 +55,10 @@ case $platform in
 		cmd="yum install -y"
 		pkgs="gcc make cmake zlib-devel openssl-devel rpm-build"
 		;;
+	Linux-arch*)
+		cmd="pacman --no-confirm -S"
+		pkgs="gcc make cmake"
+		;;
 	FreeBSD-freebsd)
 		cmd="pkg install"
 		pkgs="cmake"
